#!/bin/zsh

# You need zsh to run this

# releasecss.sh
# Release CSS-files of WWW-pages of Juhapekka Tolvanen

# Author:
# Juhapekka Tolvanen
# juhtolv (at) iki (dot) fi
# http://iki.fi/juhtolv

# This script is public domain
# There is no warranty


#WWW_DIR="${HOME}/public_html"
WWW_DIR="${HOME}/www"

#WWW_INDEX_FILE="index.php"
#WWW_INDEX_FILE="index.cgi"
WWW_INDEX_FILE="index.html"

RELEASEDIR="${WWW_DIR}/css-download"

# Does WWW-directory exist

if test -f ${WWW_DIR}/${WWW_INDEX_FILE}
then
    :
else
    echo "WWW-directory ${WWW_DIR} seems bogus. Exiting..." >&2
    echo "Exiting..." >&2
    exit 1
fi

# AFAIK star is faster and better than GNU tar
# http://www.fokus.gmd.de/research/cc/glone/employees/joerg.schilling/private/star.html
if star --version 2>&1 | grep -i "Schilling" > /dev/null 2>&1
then
    TAR_BIN='star -time -fifostats '
    echo "Cool... You have star, not just GNU tar or plain tar"
elif gtar --help 2>&1 | grep -i "gnu.org" > /dev/null 2>&1
then
    TAR_BIN="gtar"
    echo "Cool... You have GNU tar, not just plain tar"
elif tar --help 2>&1 | grep -i "gnu.org" > /dev/null 2>&1
then
    TAR_BIN="tar"
    echo "Cool... You have GNU tar, not just plain tar"
else
    echo "star or GNU tar is not installed."
    echo "Support for other tar-implementations is not yet available."
    exit 1
fi

MYDATE="`date +%Y%m%d`"
COMPRESSDIR="juhtolv-css-${MYDATE}"

mkdir /tmp/${COMPRESSDIR} 2> /dev/null
mkdir /tmp/${COMPRESSDIR}/js 2> /dev/null
mkdir /tmp/${COMPRESSDIR}/pix 2> /dev/null
mkdir /tmp/${COMPRESSDIR}/cssfonts 2> /dev/null
rm -rf /tmp/${COMPRESSDIR}/*(.) > /dev/null 2>&1

for f in importedbw.css  imported.css  indexbw.css indexbwserif.css index.css  printbw.css latex.css licenses/dsl.fi.0.2.txt licenses/dsl.txt licenses/fdl.txt pelle.html
do
    cp ${HOME}/www/"$f" /tmp/${COMPRESSDIR}/
done
cp ${HOME}/www/js/styleswitcher.js /tmp/${COMPRESSDIR}/js/
cp ${HOME}/www/cssfonts/* /tmp/${COMPRESSDIR}/cssfonts/
cp ${HOME}/www/pix/ryppy* /tmp/${COMPRESSDIR}/pix/
cp ${HOME}/www/pix/nimmari_red.png /tmp/${COMPRESSDIR}/pix/
cp ${0} /tmp/${COMPRESSDIR}/

for g in compileall.sh cleanall.sh css-download-readme.html css-download-readme.pdf css-download-readme.ps css-download-readme.tex css-download-readme.landscape.tex  css-download-readme.landscape.ps css-download-readme.landscape.pdf css-download-readme.txt docutils.conf docutils.landscape.conf RST_landscape.sty RST_Palatino_Optima.sty RST_Palatino_MPlus.sty
do
    cp ${RELEASEDIR}/${g} /tmp/${COMPRESSDIR}/
done

rm -fv  ${RELEASEDIR}/${COMPRESSDIR}.tar.bz2

cd /tmp
$TAR_BIN -v -c -f - ${COMPRESSDIR} | bzip2 -9 > ${RELEASEDIR}/${COMPRESSDIR}.tar.bz2

## What the heck I am doing with this?
#rm -rf  ${RELEASEDIR}/juhtolv-css*~*.tar.bz2 > /dev/null 2>&1

#cp -r /tmp/${COMPRESSDIR} ${RELEASEDIR}/
rm -rf /tmp/${COMPRESSDIR}

cd  ${RELEASEDIR} || exit 1

for h in *.sh *.sty docutils*conf *.pdf *.ps
do
    rm -fv "${h}.bz2"
    bzip2 -9kv "${h}"
done
chmod -R ugo+rX,go-w ${RELEASEDIR}
chmod ugo-x *.sh.bz2
chmod ugo+r *.sh



